==> foundry_platform_sdk-0.66.0.tar.gz: foundry_platform_sdk-0.66.0/foundry/v2/functions/models/_two_dimensional_aggregation.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Literal
from typing import cast

import pydantic

from foundry.v2.functions.models._query_aggregation_key_type import QueryAggregationKeyType  # NOQA
from foundry.v2.functions.models._query_aggregation_value_type import (
    QueryAggregationValueType,
)  # NOQA
from foundry.v2.functions.models._two_dimensional_aggregation_dict import (
    TwoDimensionalAggregationDict,
)  # NOQA


class TwoDimensionalAggregation(pydantic.BaseModel):
    """TwoDimensionalAggregation"""

    key_type: QueryAggregationKeyType = pydantic.Field(alias="keyType")

    value_type: QueryAggregationValueType = pydantic.Field(alias="valueType")

    type: Literal["twoDimensionalAggregation"] = "twoDimensionalAggregation"

    model_config = {"extra": "allow"}

    def to_dict(self) -> TwoDimensionalAggregationDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            TwoDimensionalAggregationDict, self.model_dump(by_alias=True, exclude_unset=True)
        )

==> foundry_platform_sdk-0.74.0.tar.gz: foundry_platform_sdk-0.74.0/foundry/v2/functions/models/_two_dimensional_aggregation.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Literal
from typing import cast

import pydantic

from foundry.v2.functions.models._query_aggregation_key_type import QueryAggregationKeyType  # NOQA
from foundry.v2.functions.models._query_aggregation_value_type import (
    QueryAggregationValueType,
)  # NOQA
from foundry.v2.functions.models._two_dimensional_aggregation_dict import (
    TwoDimensionalAggregationDict,
)  # NOQA


class TwoDimensionalAggregation(pydantic.BaseModel):
    """TwoDimensionalAggregation"""

    key_type: QueryAggregationKeyType = pydantic.Field(alias=str("keyType"))  # type: ignore[literal-required]

    value_type: QueryAggregationValueType = pydantic.Field(alias=str("valueType"))  # type: ignore[literal-required]

    type: Literal["twoDimensionalAggregation"] = "twoDimensionalAggregation"

    model_config = {"extra": "allow", "populate_by_name": True}

    def to_dict(self) -> TwoDimensionalAggregationDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            TwoDimensionalAggregationDict, self.model_dump(by_alias=True, exclude_unset=True)
        )
